@@ -3,7 +3,7 @@ import sys
 import click
 from rich.console import Console
 
-from pywhat import identifier, printer
+from pywhat import __version__, identifier, printer
 from pywhat.filter import Distribution, Filter
 from pywhat.helper import AvailableTags, InvalidTag, Keys, str_to_key
 
@@ -12,7 +12,14 @@ def print_tags(ctx, opts, value):
     if value:
         tags = sorted(AvailableTags().get_tags())
         console = Console()
-        console.print("[bold #D7Afff]" + "\n".join(tags) + "[/bold #D7Afff]")
+        console.print("[bold #D7AFFF]" + "\n".join(tags) + "[/bold #D7AFFF]")
+        sys.exit()
+
+
+def print_version(ctx, opts, value):
+    if value:
+        console = Console()
+        console.print(f"PyWhat version [bold #49C3CE]{__version__}[/bold #49C3CE]")
         sys.exit()
 
 
@@ -69,7 +76,7 @@ def create_filter(rarity, include, exclude):
     default="0.1:1",
 )
 @click.option("-i", "--include", help="Only show matches with these tags.")
-@click.option("-e", "--exclude", help="Disclude matches with these tags.")
+@click.option("-e", "--exclude", help="Exclude matches with these tags.")
 @click.option("-o", "--only-text", is_flag=True, help="Do not scan files or folders.")
 @click.option("-k", "--key", help="Sort by the specified key.")
 @click.option("--reverse", is_flag=True, help="Sort in reverse order.")
@@ -89,6 +96,19 @@ def create_filter(rarity, include, exclude):
     "-db", "--disable-boundaryless", is_flag=True, help="Disable boundaryless mode."
 )
 @click.option("--json", is_flag=True, help="Return results in json format.")
+@click.option(
+    "-v",
+    "--version",
+    is_flag=True,
+    callback=print_version,
+    help="Display the version of pywhat.",
+)
+@click.option(
+    "-if",
+    "--include-filenames",
+    is_flag=True,
+    help="Search filenames for possible matches.",
+)
 def main(**kwargs):
     """
     pyWhat - Identify what something is.
@@ -199,7 +219,12 @@ def main(**kwargs):
             print("Invalid key")
             sys.exit(1)
     identified_output = what_obj.what_is_this(
-        kwargs["text_input"], kwargs["only_text"], key, kwargs["reverse"], boundaryless
+        kwargs["text_input"],
+        kwargs["only_text"],
+        key,
+        kwargs["reverse"],
+        boundaryless,
+        kwargs["include_filenames"],
     )
 
     p = printer.Printing()
@@ -216,7 +241,13 @@ class What_Object:
         self.id = identifier.Identifier(dist=distribution)
 
     def what_is_this(
-        self, text: str, only_text: bool, key, reverse: bool, boundaryless: Filter
+        self,
+        text: str,
+        only_text: bool,
+        key,
+        reverse: bool,
+        boundaryless: Filter,
+        include_filenames: bool,
     ) -> dict:
         """
         Returns a Python dictionary of everything that has been identified
@@ -227,6 +258,7 @@ class What_Object:
             key=key,
             reverse=reverse,
             boundaryless=boundaryless,
+            include_filenames=include_filenames,
         )
 
 
